@@ -1,25 +1,14 @@
 /*
-    Copyright (C) 2004, Arend van Beelen jr. <arend@auton.nl>
-    Copyright (C) 2010, David Faure <faure@kde.org>
-
     This file is part of the KDE project
+    SPDX-FileCopyrightText: 2004 Arend van Beelen jr. <arend@auton.nl>
+    SPDX-FileCopyrightText: 2010 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2, as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LGPL-2.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
+
 #include "kfindtest.h"
 
+#include <QRegularExpression>
 #include <QTest>
 
 #include <kfind.h>
@@ -126,6 +115,7 @@ TestKFind::TestKFind()
              QLatin1String("    Boston, MA 02110-1301, USA.\n");
 }
 
+#if KTEXTWIDGETS_BUILD_DEPRECATED_SINCE(5, 70)
 void TestKFind::testStaticFindString_data()
 {
     // Tests for the core method "static KFind::find"
@@ -161,7 +151,9 @@ void TestKFind::testStaticFindString_data()
     QTest::newRow("back, at end, found") << "a" << "a" << 1 << int(KFind::FindBackwards) << 0 << 1;
     QTest::newRow("back, text shorter than pattern") << "a" << "abcd" << 0 << int(KFind::FindBackwards) << -1 << 0;
 }
+#endif
 
+#if KTEXTWIDGETS_BUILD_DEPRECATED_SINCE(5, 70)
 void TestKFind::testStaticFindString()
 {
     // Tests for the core method "static KFind::find(text, regexp)"
@@ -177,6 +169,7 @@ void TestKFind::testStaticFindString()
     QCOMPARE(result, expectedResult);
     QCOMPARE(matchedLength, expectedMatchedLength);
 }
+#endif
 
 void TestKFind::testStaticFindRegexp_data()
 {
@@ -230,10 +223,18 @@ void TestKFind::testStaticFindRegexp()
     QFETCH(int, expectedResult);
     QFETCH(int, expectedMatchedLength);
 
-    int matchedLength;
+    int matchedLength = 0;
+#if KTEXTWIDGETS_BUILD_DEPRECATED_SINCE(5, 70)
     const int result = KFind::find(text, QRegExp(pattern), startIndex, options, &matchedLength);
     QCOMPARE(result, expectedResult);
     QCOMPARE(matchedLength, expectedMatchedLength);
+
+    matchedLength = 0;
+#endif
+    const int result2 = KFind::find(text, pattern, startIndex, options | KFind::RegularExpression,
+                                    &matchedLength, nullptr);
+    QCOMPARE(result2, expectedResult);
+    QCOMPARE(matchedLength, expectedMatchedLength);
 }
 
 void TestKFind::testSimpleSearch()
@@ -280,6 +281,14 @@ void TestKFind::testLineBeginRegexp()
     QCOMPARE(test.hits().join(QString()), output);
 }
 
+void TestKFind::testLineBeginRegularExpression()
+{
+    int matchedLength;
+    QRegularExpressionMatch match;
+    KFind::find(m_text, QStringLiteral("^License.+"), 0, KFind::RegularExpression, &matchedLength, &match);
+    QCOMPARE(match.captured(0), QStringLiteral("License version 2, as published by the Free Software Foundation."));
+}
+
 void TestKFind::testFindIncremental()
 {
     // FindIncremental with static contents...
