@@ -1,27 +1,15 @@
 /*
-    Copyright (C) 2004, Arend van Beelen jr. <arend@auton.nl>
-    Copyright (C) 2010, David Faure <faure@kde.org>
-
     This file is part of the KDE project
+    SPDX-FileCopyrightText: 2004 Arend van Beelen jr. <arend@auton.nl>
+    SPDX-FileCopyrightText: 2010 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2, as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LGPL-2.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KFINDTEST_H
 #define KFINDTEST_H
 
+#include <ktextwidgets_export.h>
 #include <QObject>
 #include <QStringList>
 
@@ -73,8 +61,10 @@ public:
 
 private Q_SLOTS:
 
+#if KTEXTWIDGETS_BUILD_DEPRECATED_SINCE(5, 70)
     void testStaticFindString_data();
     void testStaticFindString();
+#endif
     void testStaticFindRegexp_data();
     void testStaticFindRegexp();
 
