@@ -1,30 +1,18 @@
-/* This file is part of the KDE libraries
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2008 Stephen Kelly <steveire@gmail.com>
+    SPDX-FileCopyrightText: 2008 Thomas McGuire <thomas.mcguire@gmx.net>
 
-   Copyright 2008 Stephen Kelly <steveire@gmail.com>
-   Copyright 2008 Thomas McGuire <thomas.mcguire@gmx.net>
-
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LGPL-2.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "krichtextwidget.h"
 
 // KDE includes
-#include <kcolorscheme.h>
-#include <kfontaction.h>
-#include <kfontsizeaction.h>
-#include <klocalizedstring.h>
+#include <KColorScheme>
+#include <KFontAction>
+#include <KFontSizeAction>
+#include <KLocalizedString>
 #include <ktoggleaction.h>
 
 // Qt includes
@@ -92,6 +80,8 @@ public:
     KToggleAction *action_text_superscript = nullptr;
     KToggleAction *action_text_subscript = nullptr;
 
+    KSelectAction *action_heading_level = nullptr;
+
     //
     // Normal functions
     //
@@ -143,6 +133,10 @@ public:
      */
     void _k_setListStyle(int index);
 
+    /**
+     * Change the heading level of a current line to a level given by @a level
+     */
+    void _k_setHeadingLevel(int level);
 };
 //@endcond
 
@@ -487,6 +481,27 @@ QList<QAction *> KRichTextWidget::createActions()
         d->action_text_superscript = nullptr;
     }
 
+    if (d->richTextSupport & SupportHeading) {
+        // TODO: an icon maybe?
+        d->action_heading_level = new KSelectAction(i18nc("@title:menu", "Heading Level"), this);
+        const QStringList headingLevels = {i18nc("@item:inmenu no heading",                 "Basic text"),
+                                           i18nc("@item:inmenu heading level 1 (largest)",  "Title"),
+                                           i18nc("@item:inmenu heading level 2",            "Subtitle"),
+                                           i18nc("@item:inmenu heading level 3",            "Section"),
+                                           i18nc("@item:inmenu heading level 4",            "Subsection"),
+                                           i18nc("@item:inmenu heading level 5",            "Paragraph"),
+                                           i18nc("@item:inmenu heading level 6 (smallest)", "Subparagraph")};
+
+        d->action_heading_level->setItems(headingLevels);
+        d->action_heading_level->setCurrentItem(0);
+        d->richTextActionList.append(d->action_heading_level);
+        d->action_heading_level->setObjectName(QStringLiteral("format_heading_level"));
+        connect(d->action_heading_level, QOverload<int>::of(&KSelectAction::triggered),
+                this, [this](int level){ d->_k_setHeadingLevel(level); });
+    } else {
+        d->action_heading_level = nullptr;
+    }
+
     disconnect(this, SIGNAL(currentCharFormatChanged(QTextCharFormat)),
                this, SLOT(_k_updateCharFormatActions(QTextCharFormat)));
     disconnect(this, SIGNAL(cursorPositionChanged()),
@@ -516,6 +531,12 @@ void KRichTextWidget::Private::_k_setListStyle(int index)
     _k_updateMiscActions();
 }
 
+void KRichTextWidget::Private::_k_setHeadingLevel(int level)
+{
+    q->setHeadingLevel(level);
+    _k_updateMiscActions();
+}
+
 void KRichTextWidget::Private::_k_updateCharFormatActions(const QTextCharFormat &format)
 {
     QFont f = format.font();
@@ -596,6 +617,10 @@ void KRichTextWidget::Private::_k_updateMiscActions()
         action_direction_ltr->setChecked(direction == Qt::LeftToRight);
         action_direction_rtl->setChecked(direction == Qt::RightToLeft);
     }
+
+    if (richTextSupport & SupportHeading) {
+        action_heading_level->setCurrentItem(q->textCursor().blockFormat().headingLevel());
+    }
 }
 
 void KRichTextWidget::Private::_k_setTextForegroundColor()
